@@ -1,4 +1,5 @@
 import argparse
+import sys
 
 from zenframe.configuration import Configuration
 
@@ -11,10 +12,12 @@ class ArgumentParser(argparse.ArgumentParser):
         self.add_argument("--unbound", action="store_true")
         self.add_argument("--display", action="store_true")
         self.add_argument("--frame", action="store_true")
+        self.add_argument("--no-show", action="store_true")
         self.add_argument("--sleeped", action="store_true",
                           help="Don't use manualy. Create sleeped thread.")
         self.add_argument("paths", type=str, nargs="*", help="runned file")
         self.add_argument("--no-restore", action="store_true")
+        self.add_argument("-m")  # for pyinstaller compatible
 
         # NOTE: Неизвестно нужны ли параметры задания геометрии.
         self.add_argument("--size")
