@@ -190,6 +190,9 @@ class ZenFrame(QtWidgets.QMainWindow, ZenFrameActionsMixin):
             self.setWindowTitle(self._current_opened)
             self.synchronize_subprocess_state()
 
+            # time.sleep(0.01)
+            # self.resize(self.size())
+
         except Exception as ex:
             self._openlock.unlock()
             print_to_stderr("exception on window bind", ex)
@@ -323,6 +326,7 @@ class ZenFrame(QtWidgets.QMainWindow, ZenFrameActionsMixin):
         pass
 
     def internal_key_pressed_raw(self, key, modifiers, text):
+        self.activateWindow()
         self.texteditor.setFocus()
         modifiers = QtCore.Qt.KeyboardModifiers()
         event = QtGui.QKeyEvent(
@@ -330,6 +334,8 @@ class ZenFrame(QtWidgets.QMainWindow, ZenFrameActionsMixin):
         QtGui.QGuiApplication.postEvent(self.texteditor, event)
 
     def internal_key_released_raw(self, key, modifiers):
+        self.activateWindow()
+        self.texteditor.setFocus()
         modifiers = QtCore.Qt.KeyboardModifiers()
         event = QtGui.QKeyEvent(QtCore.QEvent.KeyRelease,
                                 key, QtCore.Qt.KeyboardModifier(modifiers))
@@ -384,3 +390,8 @@ class ZenFrame(QtWidgets.QMainWindow, ZenFrameActionsMixin):
         # wdg.show()
         # wdg.moveToThread(QtWidgets.QApplication.instance().thread())
         self.vsplitter.replaceWidget(0, wdg)
+
+    def openStartEvent(self, path):
+        """ Добавляем путь в список последних вызовов."""
+        BaseSettings.instance().add_recent(os.path.abspath(path))
+        self.update_recent_menu()
