@@ -16,6 +16,7 @@ from zenframe.communicator import Communicator
 from zenframe.client import Client
 from zenframe.configuration import Configuration
 from zenframe.finisher import invoke_destructors
+from zenframe.animate import AnimateThread
 
 COMMUNICATOR = None
 RETRANSLER = None
@@ -62,7 +63,9 @@ def unbound_worker_top_half(top_half, bottom_half):
     BOTTOM_HALF = bottom_half
     UNBOUND_MODE = True
 
-    QAPP = QtWidgets.QApplication([])
+    QAPP = QtWidgets.QApplication.instance()
+    if QAPP is None:
+        QAPP = QtWidgets.QApplication([])
 
     # Переопределяем дескрипторы, чтобы стандартный поток вывода пошёл
     # через ретранслятор. Теперь все консольные сообщения будуут обвешиваться
@@ -146,6 +149,7 @@ def unbound_worker_bottom_half(*args, **kwargs):
     timer.start(Configuration.TIMER_PULSE * 1000)
     timer.timeout.connect(lambda: None)
 
+    AnimateThread.start_all_threads()
     QtWidgets.QApplication.instance().exec()
 
 
@@ -176,7 +180,10 @@ def start_unbounded_frame(path, application_name):
 
 
 def unbound_frame_summon(widget_creator, application_name, *args, **kwargs):
-    QAPP = QtWidgets.QApplication([])
+    QAPP = QtWidgets.QApplication.instance()
+    if QAPP is None:
+        QAPP = QtWidgets.QApplication([])
+
     CONSOLE_FILTER = ConsoleRetransler(sys.stdout, without_wrap=True)
     CONSOLE_FILTER.start_listen()
 
@@ -217,6 +224,7 @@ def unbound_frame_summon(widget_creator, application_name, *args, **kwargs):
     timer.start(500)  # You may change this if you wish.
     timer.timeout.connect(lambda: None)  # Let the interpreter run each 500 ms.
 
+    AnimateThread.start_all_threads()
     QtWidgets.QApplication.instance().exec()
 
 
