@@ -21,13 +21,11 @@ def print_to_stderr(*args):
     sys.stderr.flush()
 
 
-def create_temporary_file():
+def create_temporary_file(template):
     path = tempfile.mktemp(".py")
 
     f = open(path, "w")
-    f.write(
-        "#!/usr/bin/env python3\n#coding: utf-8\n\nfrom zenframe.unbound import unbound_worker_bottom_half\n\nprint('ZenFrame')\nunbound_worker_bottom_half()\n"
-    )
+    f.write(template)
     f.close()
 
     return path
